@@ -1,4 +1,4 @@
-def longest_substring_without_repetition(self, s):
+def longest_substring_without_repetition(s):
     start = maxLength = 0
     usedChar = {}
     
